Crate nifty_asset_types

Crate nifty_asset_types 

Nifty Asset Types defines the types that are used to represent assets on-chain.

  • Constraints - these are types to define constraints when manipulating assets. They can be used to restrict the accounts that can hold, receive or send assets.

  • Extensions - these are types that provide additional data that can be attached to an asset. They can be used to store more information about an asset on-chain or extends their behaviour.

  • State - these are the types represeting the account that store the state of an asset on-chain.

Modules

constraints
error
extensions
Extensions are used to add additional data to an asset.
podded
Re-export for downstream crates.
state

Macros

assertable_from_bytes
Macro to automate the code required to deserialize a constraint from a byte array.
get_account
Helper macro to “extract” the account from a Context given its name.